<?php

namespace Litecms\Simplepackage\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Simplepackage\Http\Requests\SimplepackageRequest;
use Litecms\Simplepackage\Interfaces\SimplepackageRepositoryInterface;
use Litecms\Simplepackage\Models\Simplepackage;

/**
 * Resource controller class for simplepackage.
 */
class SimplepackageResourceController extends BaseController
{

    /**
     * Initialize simplepackage resource controller.
     *
     * @param type SimplepackageRepositoryInterface $simplepackage
     *
     * @return null
     */
    public function __construct(SimplepackageRepositoryInterface $simplepackage)
    {
        parent::__construct();
        $this->repository = $simplepackage;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Simplepackage\Repositories\Criteria\SimplepackageResourceCriteria::class);
    }

    /**
     * Display a list of simplepackage.
     *
     * @return Response
     */
    public function index(SimplepackageRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Simplepackage\Repositories\Presenter\SimplepackagePresenter::class)
                ->$function();
        }

        $simplepackages = $this->repository->paginate();

        return $this->response->title(trans('simplepackage::simplepackage.names'))
            ->view('simplepackage::simplepackage.index', true)
            ->data(compact('simplepackages'))
            ->output();
    }

    /**
     * Display simplepackage.
     *
     * @param Request $request
     * @param Model   $simplepackage
     *
     * @return Response
     */
    public function show(SimplepackageRequest $request, Simplepackage $simplepackage)
    {

        if ($simplepackage->exists) {
            $view = 'simplepackage::simplepackage.show';
        } else {
            $view = 'simplepackage::simplepackage.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('simplepackage::simplepackage.name'))
            ->data(compact('simplepackage'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new simplepackage.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SimplepackageRequest $request)
    {

        $simplepackage = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('simplepackage::simplepackage.name')) 
            ->view('simplepackage::simplepackage.create', true) 
            ->data(compact('simplepackage'))
            ->output();
    }

    /**
     * Create new simplepackage.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SimplepackageRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $simplepackage                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('simplepackage::simplepackage.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('simplepackage/simplepackage/' . $simplepackage->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/simplepackage/simplepackage'))
                ->redirect();
        }

    }

    /**
     * Show simplepackage for editing.
     *
     * @param Request $request
     * @param Model   $simplepackage
     *
     * @return Response
     */
    public function edit(SimplepackageRequest $request, Simplepackage $simplepackage)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('simplepackage::simplepackage.name'))
            ->view('simplepackage::simplepackage.edit', true)
            ->data(compact('simplepackage'))
            ->output();
    }

    /**
     * Update the simplepackage.
     *
     * @param Request $request
     * @param Model   $simplepackage
     *
     * @return Response
     */
    public function update(SimplepackageRequest $request, Simplepackage $simplepackage)
    {
        try {
            $attributes = $request->all();

            $simplepackage->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('simplepackage::simplepackage.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('simplepackage/simplepackage/' . $simplepackage->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('simplepackage/simplepackage/' . $simplepackage->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the simplepackage.
     *
     * @param Model   $simplepackage
     *
     * @return Response
     */
    public function destroy(SimplepackageRequest $request, Simplepackage $simplepackage)
    {
        try {

            $simplepackage->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('simplepackage::simplepackage.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('simplepackage/simplepackage/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('simplepackage/simplepackage/' . $simplepackage->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple simplepackage.
     *
     * @param Model   $simplepackage
     *
     * @return Response
     */
    public function delete(SimplepackageRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('simplepackage::simplepackage.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('simplepackage/simplepackage'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/simplepackage/simplepackage'))
                ->redirect();
        }

    }

    /**
     * Restore deleted simplepackages.
     *
     * @param Model   $simplepackage
     *
     * @return Response
     */
    public function restore(SimplepackageRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('simplepackage::simplepackage.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/simplepackage/simplepackage'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/simplepackage/simplepackage/'))
                ->redirect();
        }

    }

}
